TabItem class

Inheritance

Constructors

TabItem({required UniqueKey uniqueKey, required bool selected, required IconData icon, required dynamic callbackFunction(UniqueKey uniqueKey), required Color textColor, required Color iconColor, Key? key, String? title, double iconSize = 30, double fontSize = 12, FontWeight fontWeight = FontWeight.w600})
const

Properties

callbackFunction → dynamic Function(UniqueKey uniqueKey)
final
fontSize → double
final
fontWeight → FontWeight
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
final
iconAlpha → double
final
iconColor → Color
final
iconSize → double
final
iconYAlign → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
final
textColor → Color
final
textYAlign → double
final
title → String?
final
uniqueKey → UniqueKey
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited